def firstname():
    print("Umair")


def middlename():
    print("Hamid")


def lastname():
    print("Thakur")


def name():
    print(f"""{firstname()} + " " + {middlename()} + " " + {lastname()}""")


def dob():
    print("16/08/1999")


def gender():
    print("Male")


def address():
    print("Mumbai, Maharashtra, India")


def linkedin():
    print("https://www.linkedin.com/in/umairthakur/")


def github():
    print("https://github.com/UmairThakur")


def twitter():
    print("No Account Found")


def instagram():
    print("No Account Found")


def facebook():
    print("No Account Found")


def youtube():
    print("No Account Found")


def snapchat():
    print("No Account Found")


def test():
    print("test")
    i = input("Say something: ")
    print("You said: ", i)
